#
# spec file for package libva-vdpau-driver
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libva-vdpau-driver
Version:        0.7.4
Release:        8.2
Summary:        HW video decode support for VDPAU platforms
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            http://cgit.freedesktop.org/vaapi/vdpau-driver
Source:         http://www.freedesktop.org/software/vaapi/releases/%{name}/%{name}-%{version}.tar.bz2
Patch0:         libva-vdpau-driver-0.7.4-glext-85.patch
Patch1:         libva-vdpau-driver-0.7.4-drop-h264-api.patch
Patch2:         libva-vdpau-driver-0.7.4-fix_type.patch
Patch3:         libva-vdpau-driver-0.7.4-sigfpe-crash.patch
Patch4:         libva-vdpau-driver-0.7.4-type-fix.patch
BuildRequires:  libvdpau-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(libva-x11)
# Replace a similar package from packman
Provides:       vdpau-video
Obsoletes:      vdpau-video <= %{version}-%{release}

%description
VDPAU Backend for Video Acceleration (VA) API HW video decode support.

%prep
%autosetup -p1
cat > %{name}.sh << EOF
# use this library when NVIDIA's proprietary driver is running
if test -c /dev/nvidiactl; then
  export LIBVA_DRIVER_NAME='vdpau'
  export VDPAU_DRIVER=nvidia
fi
EOF
cat > %{name}.csh << EOF
# use this library when NVIDIA's proprietary driver is running
if (-c /dev/nvidiactl) then
  setenv LIBVA_DRIVER_NAME 'vdpau'
  setenv VDPAU_DRIVER 'nvidia'
endif
EOF

%build
%configure
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}
find %{buildroot} -name '*.la' -delete
%if 0%{?suse_version} >= 1550
mkdir -p %{buildroot}%{_distconfdir}/profile.d
install -Dm 0644 %{name}.sh %{buildroot}%{_distconfdir}/profile.d/%{name}.sh
install -Dm 0644 %{name}.csh %{buildroot}%{_distconfdir}/profile.d/%{name}.csh
%else
install -Dm 0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -Dm 0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh
%endif

%files
%doc README COPYING AUTHORS NEWS
%dir %{_libdir}/dri
%{_libdir}/dri/*.so
%if 0%{?suse_version} >= 1550
%dir %{_distconfdir}/profile.d
%config %{_distconfdir}/profile.d/%{name}.*sh
%else
%config %{_sysconfdir}/profile.d/%{name}.*sh
%endif

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Aug 28 2020 Stefan Dirsch <sndirsch@suse.com>
- moved profiles for setting env variables LIBVA_DRIVER_NAME and
  VDPAU_DRIVER to /usr/etc/profiles.d on TW (boo#1173036)
* Thu Jun  4 2020 Stefan Dirsch <sndirsch@suse.com>
- in addition to setting LIBVA_DRIVER_NAME to 'vdpau' also set
  VDPAU_DRIVER to 'nvidia' if NVIDIA's proprietary drivers are
  in use, so libvdpau_nvidia.so instead of (non-existing)
  libvdpau_.so (notice the empty string after _) is being used
  (boo#1171923)
* Thu Sep  5 2019 Stefan Dirsch <sndirsch@suse.com>
- libva-vdpau-driver-0.7.4-type-fix.patch
  * typefix needed
* Tue Jan  9 2018 sndirsch@suse.com
- added "%%dir /usr/%%_lib/dri" to filelist in order to fix build
  (probably required since Mesa/Mesa-drivers split)
- no longer require Mesa-devel
* Fri Nov 17 2017 zaitor@opensuse.org
- Add libva-vdpau-driver-0.7.4-sigfpe-crash.patch: Fix a crash if a
  heap is destroyed before being initialized (fdo#58836).
- Replace libva-devel with pkgconfig(libva), pkgconfig(libva-x11)
  and pkgconfig(libva-glx) BuildRequires: Align with what configure
  looks for. Added bonus, now building GLX support too.
* Tue Feb 21 2017 olaf@aepfle.de
- Replace vdpau-video from packman
* Tue Mar 17 2015 sndirsch@suse.com
- use this library by default when NVIDIA's proprietary driver is
  running
* Mon Feb  9 2015 zaitor@opensuse.org
- Initial packaging for openSUSE.
